import reflex as rx

class GoAlert(rx.Component):
    library = "react-icons/go"
    tag = "GoAlert"


class GoAlertFill(rx.Component):
    library = "react-icons/go"
    tag = "GoAlertFill"


class GoArchive(rx.Component):
    library = "react-icons/go"
    tag = "GoArchive"


class GoArrowBoth(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowBoth"


class GoArrowDown(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowDown"


class GoArrowDownLeft(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowDownLeft"


class GoArrowDownRight(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowDownRight"


class GoArrowLeft(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowLeft"


class GoArrowRight(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowRight"


class GoArrowSwitch(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowSwitch"


class GoArrowUp(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowUp"


class GoArrowUpLeft(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowUpLeft"


class GoArrowUpRight(rx.Component):
    library = "react-icons/go"
    tag = "GoArrowUpRight"


class GoBeaker(rx.Component):
    library = "react-icons/go"
    tag = "GoBeaker"


class GoBell(rx.Component):
    library = "react-icons/go"
    tag = "GoBell"


class GoBellFill(rx.Component):
    library = "react-icons/go"
    tag = "GoBellFill"


class GoBellSlash(rx.Component):
    library = "react-icons/go"
    tag = "GoBellSlash"


class GoBlocked(rx.Component):
    library = "react-icons/go"
    tag = "GoBlocked"


class GoBold(rx.Component):
    library = "react-icons/go"
    tag = "GoBold"


class GoBook(rx.Component):
    library = "react-icons/go"
    tag = "GoBook"


class GoBookmark(rx.Component):
    library = "react-icons/go"
    tag = "GoBookmark"


class GoBookmarkFill(rx.Component):
    library = "react-icons/go"
    tag = "GoBookmarkFill"


class GoBookmarkSlash(rx.Component):
    library = "react-icons/go"
    tag = "GoBookmarkSlash"


class GoBookmarkSlashFill(rx.Component):
    library = "react-icons/go"
    tag = "GoBookmarkSlashFill"


class GoBriefcase(rx.Component):
    library = "react-icons/go"
    tag = "GoBriefcase"


class GoBroadcast(rx.Component):
    library = "react-icons/go"
    tag = "GoBroadcast"


class GoBrowser(rx.Component):
    library = "react-icons/go"
    tag = "GoBrowser"


class GoBug(rx.Component):
    library = "react-icons/go"
    tag = "GoBug"


class GoCalendar(rx.Component):
    library = "react-icons/go"
    tag = "GoCalendar"


class GoCheck(rx.Component):
    library = "react-icons/go"
    tag = "GoCheck"


class GoCheckCircle(rx.Component):
    library = "react-icons/go"
    tag = "GoCheckCircle"


class GoCheckCircleFill(rx.Component):
    library = "react-icons/go"
    tag = "GoCheckCircleFill"


class GoCheckbox(rx.Component):
    library = "react-icons/go"
    tag = "GoCheckbox"


class GoChecklist(rx.Component):
    library = "react-icons/go"
    tag = "GoChecklist"


class GoChevronDown(rx.Component):
    library = "react-icons/go"
    tag = "GoChevronDown"


class GoChevronLeft(rx.Component):
    library = "react-icons/go"
    tag = "GoChevronLeft"


class GoChevronRight(rx.Component):
    library = "react-icons/go"
    tag = "GoChevronRight"


class GoChevronUp(rx.Component):
    library = "react-icons/go"
    tag = "GoChevronUp"


class GoCircle(rx.Component):
    library = "react-icons/go"
    tag = "GoCircle"


class GoCircleSlash(rx.Component):
    library = "react-icons/go"
    tag = "GoCircleSlash"


class GoClock(rx.Component):
    library = "react-icons/go"
    tag = "GoClock"


class GoClockFill(rx.Component):
    library = "react-icons/go"
    tag = "GoClockFill"


class GoCloud(rx.Component):
    library = "react-icons/go"
    tag = "GoCloud"


class GoCloudOffline(rx.Component):
    library = "react-icons/go"
    tag = "GoCloudOffline"


class GoCode(rx.Component):
    library = "react-icons/go"
    tag = "GoCode"


class GoCodeOfConduct(rx.Component):
    library = "react-icons/go"
    tag = "GoCodeOfConduct"


class GoCodeReview(rx.Component):
    library = "react-icons/go"
    tag = "GoCodeReview"


class GoCodeSquare(rx.Component):
    library = "react-icons/go"
    tag = "GoCodeSquare"


class GoCodescan(rx.Component):
    library = "react-icons/go"
    tag = "GoCodescan"


class GoCodescanCheckmark(rx.Component):
    library = "react-icons/go"
    tag = "GoCodescanCheckmark"


class GoCodespaces(rx.Component):
    library = "react-icons/go"
    tag = "GoCodespaces"


class GoColumns(rx.Component):
    library = "react-icons/go"
    tag = "GoColumns"


class GoCommandPalette(rx.Component):
    library = "react-icons/go"
    tag = "GoCommandPalette"


class GoComment(rx.Component):
    library = "react-icons/go"
    tag = "GoComment"


class GoCommentDiscussion(rx.Component):
    library = "react-icons/go"
    tag = "GoCommentDiscussion"


class GoCommit(rx.Component):
    library = "react-icons/go"
    tag = "GoCommit"


class GoContainer(rx.Component):
    library = "react-icons/go"
    tag = "GoContainer"


class GoCopilot(rx.Component):
    library = "react-icons/go"
    tag = "GoCopilot"


class GoCopy(rx.Component):
    library = "react-icons/go"
    tag = "GoCopy"


class GoCpu(rx.Component):
    library = "react-icons/go"
    tag = "GoCpu"


class GoCreditCard(rx.Component):
    library = "react-icons/go"
    tag = "GoCreditCard"


class GoCrossReference(rx.Component):
    library = "react-icons/go"
    tag = "GoCrossReference"


class GoDash(rx.Component):
    library = "react-icons/go"
    tag = "GoDash"


class GoDatabase(rx.Component):
    library = "react-icons/go"
    tag = "GoDatabase"


class GoDependabot(rx.Component):
    library = "react-icons/go"
    tag = "GoDependabot"


class GoDesktopDownload(rx.Component):
    library = "react-icons/go"
    tag = "GoDesktopDownload"


class GoDeviceCameraVideo(rx.Component):
    library = "react-icons/go"
    tag = "GoDeviceCameraVideo"


class GoDeviceDesktop(rx.Component):
    library = "react-icons/go"
    tag = "GoDeviceDesktop"


class GoDeviceMobile(rx.Component):
    library = "react-icons/go"
    tag = "GoDeviceMobile"


class GoDiamond(rx.Component):
    library = "react-icons/go"
    tag = "GoDiamond"


class GoDiff(rx.Component):
    library = "react-icons/go"
    tag = "GoDiff"


class GoDiscussionClosed(rx.Component):
    library = "react-icons/go"
    tag = "GoDiscussionClosed"


class GoDiscussionDuplicate(rx.Component):
    library = "react-icons/go"
    tag = "GoDiscussionDuplicate"


class GoDiscussionOutdated(rx.Component):
    library = "react-icons/go"
    tag = "GoDiscussionOutdated"


class GoDot(rx.Component):
    library = "react-icons/go"
    tag = "GoDot"


class GoDotFill(rx.Component):
    library = "react-icons/go"
    tag = "GoDotFill"


class GoDownload(rx.Component):
    library = "react-icons/go"
    tag = "GoDownload"


class GoDuplicate(rx.Component):
    library = "react-icons/go"
    tag = "GoDuplicate"


class GoEye(rx.Component):
    library = "react-icons/go"
    tag = "GoEye"


class GoEyeClosed(rx.Component):
    library = "react-icons/go"
    tag = "GoEyeClosed"


class GoFile(rx.Component):
    library = "react-icons/go"
    tag = "GoFile"


class GoFileBinary(rx.Component):
    library = "react-icons/go"
    tag = "GoFileBinary"


class GoFileCode(rx.Component):
    library = "react-icons/go"
    tag = "GoFileCode"


class GoFileDiff(rx.Component):
    library = "react-icons/go"
    tag = "GoFileDiff"


class GoFileDirectory(rx.Component):
    library = "react-icons/go"
    tag = "GoFileDirectory"


class GoFileDirectoryFill(rx.Component):
    library = "react-icons/go"
    tag = "GoFileDirectoryFill"


class GoFileMedia(rx.Component):
    library = "react-icons/go"
    tag = "GoFileMedia"


class GoFileSubmodule(rx.Component):
    library = "react-icons/go"
    tag = "GoFileSubmodule"


class GoFileSymlinkFile(rx.Component):
    library = "react-icons/go"
    tag = "GoFileSymlinkFile"


class GoFileZip(rx.Component):
    library = "react-icons/go"
    tag = "GoFileZip"


class GoFilter(rx.Component):
    library = "react-icons/go"
    tag = "GoFilter"


class GoFlame(rx.Component):
    library = "react-icons/go"
    tag = "GoFlame"


class GoFold(rx.Component):
    library = "react-icons/go"
    tag = "GoFold"


class GoFoldDown(rx.Component):
    library = "react-icons/go"
    tag = "GoFoldDown"


class GoFoldUp(rx.Component):
    library = "react-icons/go"
    tag = "GoFoldUp"


class GoGear(rx.Component):
    library = "react-icons/go"
    tag = "GoGear"


class GoGift(rx.Component):
    library = "react-icons/go"
    tag = "GoGift"


class GoGitBranch(rx.Component):
    library = "react-icons/go"
    tag = "GoGitBranch"


class GoGitCommit(rx.Component):
    library = "react-icons/go"
    tag = "GoGitCommit"


class GoGitCompare(rx.Component):
    library = "react-icons/go"
    tag = "GoGitCompare"


class GoGitMerge(rx.Component):
    library = "react-icons/go"
    tag = "GoGitMerge"


class GoGitMergeQueue(rx.Component):
    library = "react-icons/go"
    tag = "GoGitMergeQueue"


class GoGitPullRequest(rx.Component):
    library = "react-icons/go"
    tag = "GoGitPullRequest"


class GoGitPullRequestClosed(rx.Component):
    library = "react-icons/go"
    tag = "GoGitPullRequestClosed"


class GoGitPullRequestDraft(rx.Component):
    library = "react-icons/go"
    tag = "GoGitPullRequestDraft"


class GoGlobe(rx.Component):
    library = "react-icons/go"
    tag = "GoGlobe"


class GoGoal(rx.Component):
    library = "react-icons/go"
    tag = "GoGoal"


class GoGrabber(rx.Component):
    library = "react-icons/go"
    tag = "GoGrabber"


class GoGraph(rx.Component):
    library = "react-icons/go"
    tag = "GoGraph"


class GoHash(rx.Component):
    library = "react-icons/go"
    tag = "GoHash"


class GoHeading(rx.Component):
    library = "react-icons/go"
    tag = "GoHeading"


class GoHeart(rx.Component):
    library = "react-icons/go"
    tag = "GoHeart"


class GoHeartFill(rx.Component):
    library = "react-icons/go"
    tag = "GoHeartFill"


class GoHistory(rx.Component):
    library = "react-icons/go"
    tag = "GoHistory"


class GoHome(rx.Component):
    library = "react-icons/go"
    tag = "GoHome"


class GoHomeFill(rx.Component):
    library = "react-icons/go"
    tag = "GoHomeFill"


class GoHorizontalRule(rx.Component):
    library = "react-icons/go"
    tag = "GoHorizontalRule"


class GoHourglass(rx.Component):
    library = "react-icons/go"
    tag = "GoHourglass"


class GoHubot(rx.Component):
    library = "react-icons/go"
    tag = "GoHubot"


class GoImage(rx.Component):
    library = "react-icons/go"
    tag = "GoImage"


class GoInbox(rx.Component):
    library = "react-icons/go"
    tag = "GoInbox"


class GoInfinity(rx.Component):
    library = "react-icons/go"
    tag = "GoInfinity"


class GoInfo(rx.Component):
    library = "react-icons/go"
    tag = "GoInfo"


class GoIssueClosed(rx.Component):
    library = "react-icons/go"
    tag = "GoIssueClosed"


class GoIssueDraft(rx.Component):
    library = "react-icons/go"
    tag = "GoIssueDraft"


class GoIssueOpened(rx.Component):
    library = "react-icons/go"
    tag = "GoIssueOpened"


class GoIssueReopened(rx.Component):
    library = "react-icons/go"
    tag = "GoIssueReopened"


class GoIssueTrackedBy(rx.Component):
    library = "react-icons/go"
    tag = "GoIssueTrackedBy"


class GoIssueTracks(rx.Component):
    library = "react-icons/go"
    tag = "GoIssueTracks"


class GoItalic(rx.Component):
    library = "react-icons/go"
    tag = "GoItalic"


class GoIterations(rx.Component):
    library = "react-icons/go"
    tag = "GoIterations"


class GoKebabHorizontal(rx.Component):
    library = "react-icons/go"
    tag = "GoKebabHorizontal"


class GoKey(rx.Component):
    library = "react-icons/go"
    tag = "GoKey"


class GoLaw(rx.Component):
    library = "react-icons/go"
    tag = "GoLaw"


class GoLightBulb(rx.Component):
    library = "react-icons/go"
    tag = "GoLightBulb"


class GoLink(rx.Component):
    library = "react-icons/go"
    tag = "GoLink"


class GoLinkExternal(rx.Component):
    library = "react-icons/go"
    tag = "GoLinkExternal"


class GoListOrdered(rx.Component):
    library = "react-icons/go"
    tag = "GoListOrdered"


class GoListUnordered(rx.Component):
    library = "react-icons/go"
    tag = "GoListUnordered"


class GoLocation(rx.Component):
    library = "react-icons/go"
    tag = "GoLocation"


class GoLock(rx.Component):
    library = "react-icons/go"
    tag = "GoLock"


class GoLog(rx.Component):
    library = "react-icons/go"
    tag = "GoLog"


class GoMail(rx.Component):
    library = "react-icons/go"
    tag = "GoMail"


class GoMegaphone(rx.Component):
    library = "react-icons/go"
    tag = "GoMegaphone"


class GoMention(rx.Component):
    library = "react-icons/go"
    tag = "GoMention"


class GoMilestone(rx.Component):
    library = "react-icons/go"
    tag = "GoMilestone"


class GoMirror(rx.Component):
    library = "react-icons/go"
    tag = "GoMirror"


class GoMoon(rx.Component):
    library = "react-icons/go"
    tag = "GoMoon"


class GoMortarBoard(rx.Component):
    library = "react-icons/go"
    tag = "GoMortarBoard"


class GoMoveToBottom(rx.Component):
    library = "react-icons/go"
    tag = "GoMoveToBottom"


class GoMoveToEnd(rx.Component):
    library = "react-icons/go"
    tag = "GoMoveToEnd"


class GoMoveToStart(rx.Component):
    library = "react-icons/go"
    tag = "GoMoveToStart"


class GoMoveToTop(rx.Component):
    library = "react-icons/go"
    tag = "GoMoveToTop"


class GoMultiSelect(rx.Component):
    library = "react-icons/go"
    tag = "GoMultiSelect"


class GoMute(rx.Component):
    library = "react-icons/go"
    tag = "GoMute"


class GoNoEntry(rx.Component):
    library = "react-icons/go"
    tag = "GoNoEntry"


class GoNorthStar(rx.Component):
    library = "react-icons/go"
    tag = "GoNorthStar"


class GoNote(rx.Component):
    library = "react-icons/go"
    tag = "GoNote"


class GoNumber(rx.Component):
    library = "react-icons/go"
    tag = "GoNumber"


class GoOrganization(rx.Component):
    library = "react-icons/go"
    tag = "GoOrganization"


class GoPackage(rx.Component):
    library = "react-icons/go"
    tag = "GoPackage"


class GoPackageDependencies(rx.Component):
    library = "react-icons/go"
    tag = "GoPackageDependencies"


class GoPackageDependents(rx.Component):
    library = "react-icons/go"
    tag = "GoPackageDependents"


class GoPaperAirplane(rx.Component):
    library = "react-icons/go"
    tag = "GoPaperAirplane"


class GoPaperclip(rx.Component):
    library = "react-icons/go"
    tag = "GoPaperclip"


class GoPasskeyFill(rx.Component):
    library = "react-icons/go"
    tag = "GoPasskeyFill"


class GoPaste(rx.Component):
    library = "react-icons/go"
    tag = "GoPaste"


class GoPencil(rx.Component):
    library = "react-icons/go"
    tag = "GoPencil"


class GoPeople(rx.Component):
    library = "react-icons/go"
    tag = "GoPeople"


class GoPerson(rx.Component):
    library = "react-icons/go"
    tag = "GoPerson"


class GoPersonAdd(rx.Component):
    library = "react-icons/go"
    tag = "GoPersonAdd"


class GoPersonFill(rx.Component):
    library = "react-icons/go"
    tag = "GoPersonFill"


class GoPin(rx.Component):
    library = "react-icons/go"
    tag = "GoPin"


class GoPlay(rx.Component):
    library = "react-icons/go"
    tag = "GoPlay"


class GoPlug(rx.Component):
    library = "react-icons/go"
    tag = "GoPlug"


class GoPlus(rx.Component):
    library = "react-icons/go"
    tag = "GoPlus"


class GoPlusCircle(rx.Component):
    library = "react-icons/go"
    tag = "GoPlusCircle"


class GoProject(rx.Component):
    library = "react-icons/go"
    tag = "GoProject"


class GoProjectRoadmap(rx.Component):
    library = "react-icons/go"
    tag = "GoProjectRoadmap"


class GoProjectSymlink(rx.Component):
    library = "react-icons/go"
    tag = "GoProjectSymlink"


class GoProjectTemplate(rx.Component):
    library = "react-icons/go"
    tag = "GoProjectTemplate"


class GoPulse(rx.Component):
    library = "react-icons/go"
    tag = "GoPulse"


class GoQuestion(rx.Component):
    library = "react-icons/go"
    tag = "GoQuestion"


class GoQuote(rx.Component):
    library = "react-icons/go"
    tag = "GoQuote"


class GoRead(rx.Component):
    library = "react-icons/go"
    tag = "GoRead"


class GoRelFilePath(rx.Component):
    library = "react-icons/go"
    tag = "GoRelFilePath"


class GoReply(rx.Component):
    library = "react-icons/go"
    tag = "GoReply"


class GoRepo(rx.Component):
    library = "react-icons/go"
    tag = "GoRepo"


class GoRepoForked(rx.Component):
    library = "react-icons/go"
    tag = "GoRepoForked"


class GoRepoLocked(rx.Component):
    library = "react-icons/go"
    tag = "GoRepoLocked"


class GoRepoPush(rx.Component):
    library = "react-icons/go"
    tag = "GoRepoPush"


class GoRepoTemplate(rx.Component):
    library = "react-icons/go"
    tag = "GoRepoTemplate"


class GoReport(rx.Component):
    library = "react-icons/go"
    tag = "GoReport"


class GoRocket(rx.Component):
    library = "react-icons/go"
    tag = "GoRocket"


class GoRows(rx.Component):
    library = "react-icons/go"
    tag = "GoRows"


class GoRss(rx.Component):
    library = "react-icons/go"
    tag = "GoRss"


class GoRuby(rx.Component):
    library = "react-icons/go"
    tag = "GoRuby"


class GoScreenFull(rx.Component):
    library = "react-icons/go"
    tag = "GoScreenFull"


class GoScreenNormal(rx.Component):
    library = "react-icons/go"
    tag = "GoScreenNormal"


class GoSearch(rx.Component):
    library = "react-icons/go"
    tag = "GoSearch"


class GoServer(rx.Component):
    library = "react-icons/go"
    tag = "GoServer"


class GoShare(rx.Component):
    library = "react-icons/go"
    tag = "GoShare"


class GoShareAndroid(rx.Component):
    library = "react-icons/go"
    tag = "GoShareAndroid"


class GoShield(rx.Component):
    library = "react-icons/go"
    tag = "GoShield"


class GoShieldCheck(rx.Component):
    library = "react-icons/go"
    tag = "GoShieldCheck"


class GoShieldLock(rx.Component):
    library = "react-icons/go"
    tag = "GoShieldLock"


class GoShieldSlash(rx.Component):
    library = "react-icons/go"
    tag = "GoShieldSlash"


class GoShieldX(rx.Component):
    library = "react-icons/go"
    tag = "GoShieldX"


class GoSidebarCollapse(rx.Component):
    library = "react-icons/go"
    tag = "GoSidebarCollapse"


class GoSidebarExpand(rx.Component):
    library = "react-icons/go"
    tag = "GoSidebarExpand"


class GoSignIn(rx.Component):
    library = "react-icons/go"
    tag = "GoSignIn"


class GoSignOut(rx.Component):
    library = "react-icons/go"
    tag = "GoSignOut"


class GoSingleSelect(rx.Component):
    library = "react-icons/go"
    tag = "GoSingleSelect"


class GoSkip(rx.Component):
    library = "react-icons/go"
    tag = "GoSkip"


class GoSkipFill(rx.Component):
    library = "react-icons/go"
    tag = "GoSkipFill"


class GoSmiley(rx.Component):
    library = "react-icons/go"
    tag = "GoSmiley"


class GoSortAsc(rx.Component):
    library = "react-icons/go"
    tag = "GoSortAsc"


class GoSortDesc(rx.Component):
    library = "react-icons/go"
    tag = "GoSortDesc"


class GoSponsorTiers(rx.Component):
    library = "react-icons/go"
    tag = "GoSponsorTiers"


class GoSquare(rx.Component):
    library = "react-icons/go"
    tag = "GoSquare"


class GoSquareFill(rx.Component):
    library = "react-icons/go"
    tag = "GoSquareFill"


class GoSquirrel(rx.Component):
    library = "react-icons/go"
    tag = "GoSquirrel"


class GoStack(rx.Component):
    library = "react-icons/go"
    tag = "GoStack"


class GoStar(rx.Component):
    library = "react-icons/go"
    tag = "GoStar"


class GoStarFill(rx.Component):
    library = "react-icons/go"
    tag = "GoStarFill"


class GoStop(rx.Component):
    library = "react-icons/go"
    tag = "GoStop"


class GoStopwatch(rx.Component):
    library = "react-icons/go"
    tag = "GoStopwatch"


class GoStrikethrough(rx.Component):
    library = "react-icons/go"
    tag = "GoStrikethrough"


class GoSun(rx.Component):
    library = "react-icons/go"
    tag = "GoSun"


class GoSync(rx.Component):
    library = "react-icons/go"
    tag = "GoSync"


class GoTab(rx.Component):
    library = "react-icons/go"
    tag = "GoTab"


class GoTable(rx.Component):
    library = "react-icons/go"
    tag = "GoTable"


class GoTag(rx.Component):
    library = "react-icons/go"
    tag = "GoTag"


class GoTasklist(rx.Component):
    library = "react-icons/go"
    tag = "GoTasklist"


class GoTelescope(rx.Component):
    library = "react-icons/go"
    tag = "GoTelescope"


class GoTelescopeFill(rx.Component):
    library = "react-icons/go"
    tag = "GoTelescopeFill"


class GoTerminal(rx.Component):
    library = "react-icons/go"
    tag = "GoTerminal"


class GoThumbsdown(rx.Component):
    library = "react-icons/go"
    tag = "GoThumbsdown"


class GoThumbsup(rx.Component):
    library = "react-icons/go"
    tag = "GoThumbsup"


class GoTools(rx.Component):
    library = "react-icons/go"
    tag = "GoTools"


class GoTrash(rx.Component):
    library = "react-icons/go"
    tag = "GoTrash"


class GoTriangleDown(rx.Component):
    library = "react-icons/go"
    tag = "GoTriangleDown"


class GoTriangleLeft(rx.Component):
    library = "react-icons/go"
    tag = "GoTriangleLeft"


class GoTriangleRight(rx.Component):
    library = "react-icons/go"
    tag = "GoTriangleRight"


class GoTriangleUp(rx.Component):
    library = "react-icons/go"
    tag = "GoTriangleUp"


class GoTrophy(rx.Component):
    library = "react-icons/go"
    tag = "GoTrophy"


class GoTypography(rx.Component):
    library = "react-icons/go"
    tag = "GoTypography"


class GoUnfold(rx.Component):
    library = "react-icons/go"
    tag = "GoUnfold"


class GoUnlink(rx.Component):
    library = "react-icons/go"
    tag = "GoUnlink"


class GoUnlock(rx.Component):
    library = "react-icons/go"
    tag = "GoUnlock"


class GoUnmute(rx.Component):
    library = "react-icons/go"
    tag = "GoUnmute"


class GoUnread(rx.Component):
    library = "react-icons/go"
    tag = "GoUnread"


class GoUnverified(rx.Component):
    library = "react-icons/go"
    tag = "GoUnverified"


class GoUpload(rx.Component):
    library = "react-icons/go"
    tag = "GoUpload"


class GoVerified(rx.Component):
    library = "react-icons/go"
    tag = "GoVerified"


class GoVersions(rx.Component):
    library = "react-icons/go"
    tag = "GoVersions"


class GoVideo(rx.Component):
    library = "react-icons/go"
    tag = "GoVideo"


class GoWorkflow(rx.Component):
    library = "react-icons/go"
    tag = "GoWorkflow"


class GoX(rx.Component):
    library = "react-icons/go"
    tag = "GoX"


class GoXCircle(rx.Component):
    library = "react-icons/go"
    tag = "GoXCircle"


class GoXCircleFill(rx.Component):
    library = "react-icons/go"
    tag = "GoXCircleFill"


class GoZap(rx.Component):
    library = "react-icons/go"
    tag = "GoZap"


class GoZoomIn(rx.Component):
    library = "react-icons/go"
    tag = "GoZoomIn"


class GoZoomOut(rx.Component):
    library = "react-icons/go"
    tag = "GoZoomOut"


